@@ -37,9 +37,7 @@ def test_calling_cookiecutter_on_prod_template_with_mkdocs_builder(
     # assert expected_default_context_passed['docs_builder'] == 'mkdocs'
     expected_extra_context_passed = None
     if 'interpreters' in user_config_dict:
-        expected_extra_context_passed = {
-            'interpreters': user_config_dict['interpreters']
-        }
+        expected_extra_context_passed = {'interpreters': user_config_dict['interpreters']}
 
     # Track the Jinja Context for SANITY Check
     from cookiecutter.generate import generate_context
